Class: Elasticsearch::Extensions::ANSI::ResponseBody
- Inherits:
-
Hash
- Object
- Hash
- Elasticsearch::Extensions::ANSI::ResponseBody
- Defined in:
- lib/elasticsearch/extensions/ansi/response.rb
Overview
Wrapper for the Elasticsearch response body, which adds a #to_ansi method
Instance Method Summary collapse
-
#initialize(body) ⇒ ResponseBody
constructor
A new instance of ResponseBody.
-
#to_ansi(options = {}) ⇒ Object
Return a colorized and formatted representation of the Elasticsearch response for:.
Constructor Details
#initialize(body) ⇒ ResponseBody
Returns a new instance of ResponseBody.
25 26 27 |
# File 'lib/elasticsearch/extensions/ansi/response.rb', line 25 def initialize(body) super(body) end |
Instance Method Details
#to_ansi(options = {}) ⇒ Object
TODO:
Add all facets and handlers for remaining response parts / types
Return a colorized and formatted representation of the Elasticsearch response for:
- Search results (hits and highlights)
- Facets (terms, statistical, histogram, date_histogram)
- Analyze API output
- Shard allocation
44 45 46 47 48 49 50 51 52 53 54 55 56 |
# File 'lib/elasticsearch/extensions/ansi/response.rb', line 44 def to_ansi(={}) output = Actions.public_methods.select do |m| m.to_s =~ /^display_/ end.map do |m| Actions.send(m, self, ) end unless output.compact.empty? output.compact.join("\n") else self.respond_to?(:awesome_inspect) ? self.awesome_inspect : self.inspect end end |